package com.qianhe.service.impl;

import java.util.ArrayList;
import java.util.List;
import com.qianhe.common.utils.DateUtils;
import com.qianhe.common.utils.SecurityUtils;
import com.qianhe.domain.WorkXmcb;
import com.qianhe.mapper.WorkXmcbMapper;
import com.qianhe.vo.WorkXmTjVo;
import com.qianhe.vo.WorkXmVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.qianhe.mapper.WorkXmMapper;
import com.qianhe.domain.WorkXm;
import com.qianhe.service.IWorkXmService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 项目Service业务层处理
 *
 * @author qianhe
 * @date 2024-01-17
 */
@Service
public class WorkXmServiceImpl implements IWorkXmService
{
    @Autowired
    private WorkXmMapper workXmMapper;
    @Autowired
    private WorkXmcbMapper workXmcbMapper;

    /**
     * 查询项目
     *
     * @param id 项目主键
     * @return 项目
     */
    @Override
    public WorkXm selectWorkXmById(Long id)
    {
        return workXmMapper.selectWorkXmById(id);
    }

    /**
     * 查询项目列表
     *
     * @param workXm 项目
     * @return 项目
     */
    @Override
    public List<WorkXm> selectWorkXmList(WorkXm workXm)
    {
        return workXmMapper.selectWorkXmList(workXm);
    }

    /**
     * 新增项目
     *
     * @param workXm 项目
     * @return 结果
     */
    @Override
    public int insertWorkXm(WorkXm workXm)
    {
        workXm.setTbrId(SecurityUtils.getUserId());
        workXm.setTbsj(DateUtils.getNowDate());
        workXm.setDqjdmc("压裂通知");
        workXm.setCreateBy(SecurityUtils.getUsername());
        workXm.setCreateTime(DateUtils.getNowDate());
        return workXmMapper.insertWorkXm(workXm);
    }

    /**
     * 修改项目
     *
     * @param workXm 项目
     * @return 结果
     */
    @Override
    public int updateWorkXm(WorkXm workXm)
    {
        workXm.setUpdateBy(SecurityUtils.getUsername());
        workXm.setUpdateTime(DateUtils.getNowDate());
        return workXmMapper.updateWorkXm(workXm);
    }

    /**
     * 批量删除项目
     *
     * @param ids 需要删除的项目主键
     * @return 结果
     */
    @Override
    public int deleteWorkXmByIds(Long[] ids)
    {
        //批量删除项目从表信息
        workXmMapper.deleteWorkXmCbByYltzIds(ids);
        return workXmMapper.deleteWorkXmByIds(ids);
    }

    /**
     * 删除项目信息
     *
     * @param id 项目主键
     * @return 结果
     */
    @Override
    public int deleteWorkXmById(Long id)
    {
        return workXmMapper.deleteWorkXmById(id);
    }

    /**
     * 提交
     * @param workXm
     * @return
     */
    @Override
    @Transactional
    public int submit(WorkXm workXm) {
        workXm.setLczt("1");
        workXm.setTjzt("1");
        workXm.setDqjdmc("采集设计");
        int i = workXmMapper.updateWorkXm(workXm);
        //新增操作历史表
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(workXm.getId());
        workXmcb.setShrId(SecurityUtils.getUserId());
        workXmcb.setShrlx("0");
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcb.setWczt("1");
        workXmcb.setSfsctj("1");
        workXmcb.setCreateBy(SecurityUtils.getUsername());
        workXmcb.setCreateTime(DateUtils.getNowDate());
        workXmcbMapper.insertWorkXmcb(workXmcb);
        return i;
    }

    /**
     * 查询项目详情
     * @param id
     * @return
     */
    @Override
    public WorkXmVo getXmInfo(Long id) {
        WorkXm workXm = workXmMapper.selectWorkXmById(id);
        //转vo
        WorkXmVo workXmVo = new WorkXmVo();
        BeanUtils.copyProperties(workXm,workXmVo);
        //查询监测设计图集合
        workXmVo.setJcsjtList(workXmMapper.selectFile(id,"项目-监测设计图"));
        //查询布设坐标集合
        workXmVo.setBszbList(workXmMapper.selectFile(id,"项目-布设坐标"));
        //查询试油工程设计集合
        workXmVo.setSygcsjList(workXmMapper.selectFile(id,"项目-试油工程设计"));
        //查询其他附件集合
        workXmVo.setQtList(workXmMapper.selectFile(id,"项目-其他附件"));
        return workXmVo;
    }

    /**
     * 工作量统计
     * @param workXmVo
     * @return
     */
    @Override
    public List<WorkXmTjVo> getGzlTjList(WorkXmVo workXmVo) {
        //查询所有已提交的项目
        workXmVo.setTjzt("1");
        List<WorkXm> workXms = workXmMapper.selectWorkXmGzlList(workXmVo);
        //查询所有审批历史
        List<WorkXmcb> workXmcbs = workXmcbMapper.selectWorkXmcbList(new WorkXmcb());
        List<WorkXmTjVo> list = new ArrayList<>();
        for (WorkXm xm : workXms) {
            WorkXmTjVo workXmTjVo1 = new WorkXmTjVo();
            workXmTjVo1.setJh(xm.getJh());
            for (WorkXmcb workXmcb : workXmcbs) {
                if (xm.getId().equals(workXmcb.getYltzId())){
                    switch (workXmcb.getShrlx()){
                        case "0":
                            workXmTjVo1.setYltz(workXmcb.getShr());
                            break;
                        case "1":
                            workXmTjVo1.setCjsj(workXmcb.getShr());
                            break;
                        case "2":
                            workXmTjVo1.setSjsh(workXmcb.getShr());
                            break;
                        case "3":
                            workXmTjVo1.setXckc(workXmcb.getShr());
                            break;
                        default:break;
                    }
                }
            }
            list.add(workXmTjVo1);
        }
        return list;
    }
}
